pub struct FileChangeReview {
pub path: PathBuf,
pub before: Option<Vec<u8>>,
pub after: Vec<u8>,
}Expand description
Host-neutral material needed to review a file mutation.
Keeping bytes instead of UTF-8 strings preserves the source behavior for an existing file whose contents are not valid Unicode. Presentation layers are responsible for producing a bounded textual or binary-aware diff.
Fields
path: PathBufbefore: Option<Vec<u8>>after: Vec<u8>Trait Implementations
Sourceimpl Clone for FileChangeReview
impl Clone for FileChangeReview
Sourcefn clone(&self) -> FileChangeReview
fn clone(&self) -> FileChangeReview
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileChangeReview
impl Debug for FileChangeReview
impl Eq for FileChangeReview
Sourceimpl PartialEq for FileChangeReview
impl PartialEq for FileChangeReview
impl StructuralPartialEq for FileChangeReview