ReadEvidenceStore

Trait ReadEvidenceStore 

pub trait ReadEvidenceStore: Send + Sync {
    // Required methods
    fn record(&self, path: PathBuf, evidence: ReadEvidence);
    fn lookup(&self, path: &Path) -> Option<ReadEvidence>;
    fn remove(&self, path: &Path);
}
Session-scoped read evidence port.

Hosts may replace the in-memory implementation when reads happen in a remote workspace or need to be projected into a durable session log.

Required Methods

fn record(&self, path: PathBuf, evidence: ReadEvidence)

fn lookup(&self, path: &Path) -> Option<ReadEvidence>

fn remove(&self, path: &Path)

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors