pub trait ContextProjector: Send + Sync {
// Required method
fn project(
&self,
messages: &[ChatMessage],
max_tokens: usize,
) -> ContextProjection;
}Expand description
Projects durable conversation state into one bounded provider request. Canonical history remains untouched for storage, replay, and audit.
Required Methods
fn project( &self, messages: &[ChatMessage], max_tokens: usize, ) -> ContextProjection
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".